@@ -72,7 +72,7 @@ def send_notifications(email, sender, email_configuration):
     # LOG_PATH = email_configuration.get('Log_path')
     ATTACHMENT = getattr(settings, "LOG_PATH", None)
 
-    zipf = zipfile.ZipFile('Zipped_file.zip', 'w', zipfile.ZIP_DEFLATED)
+    zipf = zipfile.ZipFile('media/Zipped_file.zip', 'w', zipfile.ZIP_DEFLATED)
     zipdir(ATTACHMENT, zipf)
     zipf.close()
 
@@ -85,13 +85,13 @@ def send_notifications(email, sender, email_configuration):
         faq_url=email_configuration.get('FAQ_URL'),
         unsubscribe=email_configuration.get('Unsubscribe_Email_ID'))
     # Define the attachment part and encode it using MIMEApplication.
-    att = MIMEApplication(open('Zipped_file.zip', 'rb').read())
-    os.remove('Zipped_file.zip')
+    att = MIMEApplication(open('media/Zipped_file.zip', 'rb').read())
+    # os.remove('Zipped_file.zip')
 
     # Add a header to tell the email client to treat this part as an
     # attachment, and to give the attachment a name.
     att.add_header('Content-Disposition', 'attachment',
-                   filename="OpenLXP notifications ")
+                   filename="OpenLXP notifications"+".zip")
 
     for each_recipient in RECIPIENT:
         try:
